==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/PullRequestLintOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for PullRequestLint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.769Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestLintOptions")
@software.amazon.jsii.Jsii.Proxy(PullRequestLintOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PullRequestLintOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Github Runner selection labels.
     * <p>
     * Default: ["ubuntu-latest"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRunsOn() {
        return null;
    }

    /**
     * (experimental) Validate that pull request titles follow Conventional Commits.
     * <p>
     * Default: true
     * <p>
     * @see https://www.conventionalcommits.org/
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSemanticTitle() {
        return null;
    }

    /**
     * (experimental) Options for validating the conventional commit title linter.
     * <p>
     * Default: - title must start with "feat", "fix", or "chore"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.SemanticTitleOptions getSemanticTitleOptions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PullRequestLintOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PullRequestLintOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PullRequestLintOptions> {
        java.util.List<java.lang.String> runsOn;
        java.lang.Boolean semanticTitle;
        io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions;

        /**
         * Sets the value of {@link PullRequestLintOptions#getRunsOn}
         * @param runsOn Github Runner selection labels.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(java.util.List<java.lang.String> runsOn) {
            this.runsOn = runsOn;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getSemanticTitle}
         * @param semanticTitle Validate that pull request titles follow Conventional Commits.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitle(java.lang.Boolean semanticTitle) {
            this.semanticTitle = semanticTitle;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getSemanticTitleOptions}
         * @param semanticTitleOptions Options for validating the conventional commit title linter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitleOptions(io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions) {
            this.semanticTitleOptions = semanticTitleOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PullRequestLintOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PullRequestLintOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PullRequestLintOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PullRequestLintOptions {
        private final java.util.List<java.lang.String> runsOn;
        private final java.lang.Boolean semanticTitle;
        private final io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.runsOn = software.amazon.jsii.Kernel.get(this, "runsOn", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.semanticTitle = software.amazon.jsii.Kernel.get(this, "semanticTitle", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.semanticTitleOptions = software.amazon.jsii.Kernel.get(this, "semanticTitleOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.SemanticTitleOptions.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.runsOn = builder.runsOn;
            this.semanticTitle = builder.semanticTitle;
            this.semanticTitleOptions = builder.semanticTitleOptions;
        }

        @Override
        public final java.util.List<java.lang.String> getRunsOn() {
            return this.runsOn;
        }

        @Override
        public final java.lang.Boolean getSemanticTitle() {
            return this.semanticTitle;
        }

        @Override
        public final io.github.cdklabs.projen.github.SemanticTitleOptions getSemanticTitleOptions() {
            return this.semanticTitleOptions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRunsOn() != null) {
                data.set("runsOn", om.valueToTree(this.getRunsOn()));
            }
            if (this.getSemanticTitle() != null) {
                data.set("semanticTitle", om.valueToTree(this.getSemanticTitle()));
            }
            if (this.getSemanticTitleOptions() != null) {
                data.set("semanticTitleOptions", om.valueToTree(this.getSemanticTitleOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.PullRequestLintOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PullRequestLintOptions.Jsii$Proxy that = (PullRequestLintOptions.Jsii$Proxy) o;

            if (this.runsOn != null ? !this.runsOn.equals(that.runsOn) : that.runsOn != null) return false;
            if (this.semanticTitle != null ? !this.semanticTitle.equals(that.semanticTitle) : that.semanticTitle != null) return false;
            return this.semanticTitleOptions != null ? this.semanticTitleOptions.equals(that.semanticTitleOptions) : that.semanticTitleOptions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.runsOn != null ? this.runsOn.hashCode() : 0;
            result = 31 * result + (this.semanticTitle != null ? this.semanticTitle.hashCode() : 0);
            result = 31 * result + (this.semanticTitleOptions != null ? this.semanticTitleOptions.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/PullRequestLintOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for PullRequestLint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.435Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestLintOptions")
@software.amazon.jsii.Jsii.Proxy(PullRequestLintOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PullRequestLintOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Require a contributor statement to be included in the PR description.
     * <p>
     * For example confirming that the contribution has been made by the contributor and complies with the project's license.
     * <p>
     * Appends the statement to the end of the Pull Request template.
     * <p>
     * Default: - no contributor statement is required
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getContributorStatement() {
        return null;
    }

    /**
     * (experimental) Options for requiring a contributor statement on Pull Requests.
     * <p>
     * Default: - none
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.ContributorStatementOptions getContributorStatementOptions() {
        return null;
    }

    /**
     * (experimental) Github Runner selection labels.
     * <p>
     * Default: ["ubuntu-latest"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRunsOn() {
        return null;
    }

    /**
     * (experimental) Github Runner Group selection options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.GroupRunnerOptions getRunsOnGroup() {
        return null;
    }

    /**
     * (experimental) Validate that pull request titles follow Conventional Commits.
     * <p>
     * Default: true
     * <p>
     * @see <a href="https://www.conventionalcommits.org/">https://www.conventionalcommits.org/</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getSemanticTitle() {
        return null;
    }

    /**
     * (experimental) Options for validating the conventional commit title linter.
     * <p>
     * Default: - title must start with "feat", "fix", or "chore"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.SemanticTitleOptions getSemanticTitleOptions() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PullRequestLintOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PullRequestLintOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PullRequestLintOptions> {
        java.lang.String contributorStatement;
        io.github.cdklabs.projen.github.ContributorStatementOptions contributorStatementOptions;
        java.util.List<java.lang.String> runsOn;
        io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup;
        java.lang.Boolean semanticTitle;
        io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions;

        /**
         * Sets the value of {@link PullRequestLintOptions#getContributorStatement}
         * @param contributorStatement Require a contributor statement to be included in the PR description.
         *                             For example confirming that the contribution has been made by the contributor and complies with the project's license.
         *                             <p>
         *                             Appends the statement to the end of the Pull Request template.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contributorStatement(java.lang.String contributorStatement) {
            this.contributorStatement = contributorStatement;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getContributorStatementOptions}
         * @param contributorStatementOptions Options for requiring a contributor statement on Pull Requests.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder contributorStatementOptions(io.github.cdklabs.projen.github.ContributorStatementOptions contributorStatementOptions) {
            this.contributorStatementOptions = contributorStatementOptions;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getRunsOn}
         * @param runsOn Github Runner selection labels.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(java.util.List<java.lang.String> runsOn) {
            this.runsOn = runsOn;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getRunsOnGroup}
         * @param runsOnGroup Github Runner Group selection options.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOnGroup(io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup) {
            this.runsOnGroup = runsOnGroup;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getSemanticTitle}
         * @param semanticTitle Validate that pull request titles follow Conventional Commits.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitle(java.lang.Boolean semanticTitle) {
            this.semanticTitle = semanticTitle;
            return this;
        }

        /**
         * Sets the value of {@link PullRequestLintOptions#getSemanticTitleOptions}
         * @param semanticTitleOptions Options for validating the conventional commit title linter.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder semanticTitleOptions(io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions) {
            this.semanticTitleOptions = semanticTitleOptions;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PullRequestLintOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PullRequestLintOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link PullRequestLintOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PullRequestLintOptions {
        private final java.lang.String contributorStatement;
        private final io.github.cdklabs.projen.github.ContributorStatementOptions contributorStatementOptions;
        private final java.util.List<java.lang.String> runsOn;
        private final io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup;
        private final java.lang.Boolean semanticTitle;
        private final io.github.cdklabs.projen.github.SemanticTitleOptions semanticTitleOptions;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.contributorStatement = software.amazon.jsii.Kernel.get(this, "contributorStatement", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.contributorStatementOptions = software.amazon.jsii.Kernel.get(this, "contributorStatementOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.ContributorStatementOptions.class));
            this.runsOn = software.amazon.jsii.Kernel.get(this, "runsOn", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.runsOnGroup = software.amazon.jsii.Kernel.get(this, "runsOnGroup", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.GroupRunnerOptions.class));
            this.semanticTitle = software.amazon.jsii.Kernel.get(this, "semanticTitle", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.semanticTitleOptions = software.amazon.jsii.Kernel.get(this, "semanticTitleOptions", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.SemanticTitleOptions.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.contributorStatement = builder.contributorStatement;
            this.contributorStatementOptions = builder.contributorStatementOptions;
            this.runsOn = builder.runsOn;
            this.runsOnGroup = builder.runsOnGroup;
            this.semanticTitle = builder.semanticTitle;
            this.semanticTitleOptions = builder.semanticTitleOptions;
        }

        @Override
        public final java.lang.String getContributorStatement() {
            return this.contributorStatement;
        }

        @Override
        public final io.github.cdklabs.projen.github.ContributorStatementOptions getContributorStatementOptions() {
            return this.contributorStatementOptions;
        }

        @Override
        public final java.util.List<java.lang.String> getRunsOn() {
            return this.runsOn;
        }

        @Override
        public final io.github.cdklabs.projen.GroupRunnerOptions getRunsOnGroup() {
            return this.runsOnGroup;
        }

        @Override
        public final java.lang.Boolean getSemanticTitle() {
            return this.semanticTitle;
        }

        @Override
        public final io.github.cdklabs.projen.github.SemanticTitleOptions getSemanticTitleOptions() {
            return this.semanticTitleOptions;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getContributorStatement() != null) {
                data.set("contributorStatement", om.valueToTree(this.getContributorStatement()));
            }
            if (this.getContributorStatementOptions() != null) {
                data.set("contributorStatementOptions", om.valueToTree(this.getContributorStatementOptions()));
            }
            if (this.getRunsOn() != null) {
                data.set("runsOn", om.valueToTree(this.getRunsOn()));
            }
            if (this.getRunsOnGroup() != null) {
                data.set("runsOnGroup", om.valueToTree(this.getRunsOnGroup()));
            }
            if (this.getSemanticTitle() != null) {
                data.set("semanticTitle", om.valueToTree(this.getSemanticTitle()));
            }
            if (this.getSemanticTitleOptions() != null) {
                data.set("semanticTitleOptions", om.valueToTree(this.getSemanticTitleOptions()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.PullRequestLintOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PullRequestLintOptions.Jsii$Proxy that = (PullRequestLintOptions.Jsii$Proxy) o;

            if (this.contributorStatement != null ? !this.contributorStatement.equals(that.contributorStatement) : that.contributorStatement != null) return false;
            if (this.contributorStatementOptions != null ? !this.contributorStatementOptions.equals(that.contributorStatementOptions) : that.contributorStatementOptions != null) return false;
            if (this.runsOn != null ? !this.runsOn.equals(that.runsOn) : that.runsOn != null) return false;
            if (this.runsOnGroup != null ? !this.runsOnGroup.equals(that.runsOnGroup) : that.runsOnGroup != null) return false;
            if (this.semanticTitle != null ? !this.semanticTitle.equals(that.semanticTitle) : that.semanticTitle != null) return false;
            return this.semanticTitleOptions != null ? this.semanticTitleOptions.equals(that.semanticTitleOptions) : that.semanticTitleOptions == null;
        }

        @Override
        public final int hashCode() {
            int result = this.contributorStatement != null ? this.contributorStatement.hashCode() : 0;
            result = 31 * result + (this.contributorStatementOptions != null ? this.contributorStatementOptions.hashCode() : 0);
            result = 31 * result + (this.runsOn != null ? this.runsOn.hashCode() : 0);
            result = 31 * result + (this.runsOnGroup != null ? this.runsOnGroup.hashCode() : 0);
            result = 31 * result + (this.semanticTitle != null ? this.semanticTitle.hashCode() : 0);
            result = 31 * result + (this.semanticTitleOptions != null ? this.semanticTitleOptions.hashCode() : 0);
            return result;
        }
    }
}
